#
# spec file for package unetbootin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rev 702
Name:           unetbootin
Version:        0.0.%{rev}
Release:        bp154.1.68
Summary:        Universal Netboot Installer
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://sourceforge.net/projects/unetbootin/
#Source:         %%{name}-source-%%{rev}.tar.gz
Source:         https://downloads.sourceforge.net/project/unetbootin/UNetbootin/%{rev}/unetbootin-source-%{rev}.tar.gz
Patch0:         %{name}-suse.patch
Patch1:         %{name}-locate-usb-devices.diff
Patch2:         %{name}-desktop.patch
BuildRequires:  gcc-c++
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  hicolor-icon-theme
Requires:       mtools
Requires:       syslinux
Requires:       udev
Requires:       util-linux
Requires:       xdg-utils
%if 0%{?suse_version} < 1330
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
%endif
# Requires syslinux, and that only exists for the following arches:
ExclusiveArch:  %{ix86} x86_64
# Remove when p7zip-full is in all products
%if 0%{?suse_version} >= 1500
Requires:       p7zip-full
%else
Requires:       p7zip
%endif

%description
UNetbootin allows for the installation of various Linux/BSD distributions
to a partition or USB drive, so it's no different from a standard install,
only it doesn't need a CD. It can create a dual-boot install,
or replace the existing OS entirely.

%prep
%setup -q -c -n %{name}
%patch0 -p1
%patch1 -p1
%patch2
# rpmlint: wrong-file-end-of-line-encoding
sed -i 's/\r$//' README.TXT

%build
lupdate-qt5 unetbootin.pro
lrelease-qt5 unetbootin.pro
%qmake5 "DEFINES += NOSTATIC" "RESOURCES -= unetbootin.qrc"
%if 0%{?suse_version} < 1500
%{__make} %{?_smp_mflags}
%else
%make_build
%endif
%install
install -D -m 0755 %{name} %{buildroot}%{_sbindir}/%{name}
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -D -m 0644 unetbootin_*.qm %{buildroot}%{_datadir}/%{name}

for i in 16 22 24 32 48 64 128 192 256 ; do
  install -D -m 0644 unetbootin_"$i".png %{buildroot}%{_datadir}/icons/hicolor/"$i"x"$i"/apps/%{name}.png;
done

install -D -m 0644 %{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

%if 0%{?suse_version} < 1330
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%doc README.TXT
%{_sbindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Tue Jun 22 2021 Fusion Future <qydwhotmail@gmail.com>
- Ignore %%desktop_database_post, %%desktop_database_postun,
  %%icon_theme_cache_post and %%icon_theme_cache_postun in newer releases.
- Fix build error on SLE 12 SP4 and SLE 12 SP5
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- update to 702:
  * Fix compatibility issue on macOS big sur
* Tue Jan 19 2021 ecsos <ecsos@opensuse.org>
- Update to revision 700
- Refresh unetbootin-suse.patch:
  - Remove Leap_15.1 and and Leap_15.2
- Drop 0001-rought-Qt5-port.patch, because now in upstream.
- Drop 0002-comment-out-all-sources-that-require-FTP-LIST.patch,
  because now in upstream.
- Drop 0003-fix-distrolst.cpp.patch, because now in upstream.
- Drop 0004-don-t-wait-until-the-file-is-downloaded-fully-before.patch,
  because now in upstream.
* Tue Sep  8 2020 ecsos <ecsos@opensuse.org>
- Update to revision 681
- Change selectable openSUSE versions only to supported versions:
  Leap_15.1, Leap_15.2, Tumbleweed, Factory
- Rebase patches.
- Run spec-cleaner
* Mon Apr  1 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Qt5 port patches from https://github.com/unetbootin/unetbootin/pull/137:
  * 0001-rought-Qt5-port.patch
  * 0002-comment-out-all-sources-that-require-FTP-LIST.patch
  * 0003-fix-distrolst.cpp.patch
  * 0004-don-t-wait-until-the-file-is-downloaded-fully-before.patch
- Refresh unetbootin-suse.patch:
  * add Leap 15.0 and 15.1
  * Update the download URLs and the distro description
- Refresh unetbootin-locate-usb-devices.diff
- Run spec-cleaner
* Mon Oct 15 2018 sean@suspend.net
- update to revision 661
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z binary needed by unetbootin was
  moved to this package (see bsc#899627 for more details about
  this change)
* Tue Dec 26 2017 joerg.lorenzen@ki.tng.de
- update to revision 657
* Thu Aug  3 2017 joerg.lorenzen@ki.tng.de
- update to revision 655
- added Leap_42.3 to supported versions
- fixed unetbootin-locate-usb-devices.diff
* Sat Jun 17 2017 joerg.lorenzen@ki.tng.de
- update to revision 647
- change selectable openSUSE versions only to supported versions:
  13.2, Leap_42.1, Leap_42.2, Tumbleweed, Factory
* Tue Jun 28 2016 chris@computersalat.de
- rebase patches
- fix changelog
* Wed Jun 22 2016 ecsos@opensuse.org
- change selectable openSUSE versions only to supported versions:
  13.1, 13.2, Leap_42.1, Tumbleweed, Factory
- change my old email to the new one in previous changes
* Mon Jun 20 2016 joerg.lorenzen@ki.tng.de
- update to revision 625
* Mon Dec  7 2015 dmueller@suse.com
- exclude from build on aarch64, not installable
* Tue Aug 11 2015 joerg.lorenzen@ki.tng.de
- update to revision 613
- removed source file unetbootin.desktop and added patch
  unetbootin-desktop.patch to install original desktop file
- build with %%optflags
- some clean ups in specfile
* Thu Jan 15 2015 hpj@urpla.net
- slightly clean up unetbootin-locate-usb-devices.diff patch
* Thu Dec 11 2014 hpj@urpla.net
- locate usb drives via /dev/disk/py-path in order to workaround
  udev issues
* Sun Nov  9 2014 ecsos@opensuse.org
- change selectable openSUSE versions only to supported versions:
  12.3, 13.1, 13.2, Tumbleweed, Factory
* Sun Sep  7 2014 ecsos@opensuse.org
- update to 608
* Mon May  5 2014 ecsos@opensuse.org
- update to 603
- add unetbootin.desktop
- rework suse patch
* Wed Jul 17 2013 chris@computersalat.de
- update to 585
- rework suse patch
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
* Fri May 11 2012 chris@computersalat.de
- update to 575
- rework suse patch
* Wed Jun  1 2011 prusnak@opensuse.org
- updated to 549
* Thu Mar 24 2011 chris@computersalat.de
- update to 506
- reworked suse patch
* Sat Feb  5 2011 chris@computersalat.de
- update to 502
* Fri Oct 22 2010 chris@computersalat.de
- update to revision 494
- added suse patch
* Mon Apr 26 2010 prusnak@suse.cz
- updated to revision 433
* Mon Oct  5 2009 prusnak@suse.cz
- updated to revision 372
* Mon Jun 15 2009 prusnak@suse.cz
- updated to revision 356
* Mon Jun  1 2009 prusnak@suse.cz
- updated to revision 344
* Wed Dec 10 2008 prusnak@suse.cz
- updated to revision 301
* Mon Aug 18 2008 prusnak@suse.cz
- created package - revision 272
